
#ifndef __baconvideowidget_marshal_MARSHAL_H__
#define __baconvideowidget_marshal_MARSHAL_H__

#include	<glib-object.h>

G_BEGIN_DECLS

/* VOID:INT64,INT64,FLOAT (./baconvideowidget-marshal.list:1) */
extern void baconvideowidget_marshal_VOID__INT64_INT64_FLOAT (GClosure     *closure,
                                                              GValue       *return_value,
                                                              guint         n_param_values,
                                                              const GValue *param_values,
                                                              gpointer      invocation_hint,
                                                              gpointer      marshal_data);

/* VOID:STRING,BOOLEAN (./baconvideowidget-marshal.list:2) */
extern void baconvideowidget_marshal_VOID__STRING_BOOLEAN (GClosure     *closure,
                                                           GValue       *return_value,
                                                           guint         n_param_values,
                                                           const GValue *param_values,
                                                           gpointer      invocation_hint,
                                                           gpointer      marshal_data);

G_END_DECLS

#endif /* __baconvideowidget_marshal_MARSHAL_H__ */

